LogType enum
Used to represent the various levels of logs.
Values
- VERBOSE → const LogType
-
Show all logs.
Level: 2
const LogType(2) - DEBUG → const LogType
-
Show debug.
Will also log:
Level: 3
const LogType(3) - INFO → const LogType
-
Show some informations.
Will also log
Level: 4
const LogType(4) - WARN → const LogType
-
Show only warnings.
Will also log:
Level: 5
const LogType(5) - ERROR → const LogType
-
Show only errors.
Level: 6
const LogType(6)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Int value that represent the log.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited